==> nocc-1.9.5.txz: usr/local/www/nocc/lang/ca.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ca.php 2602 2014-03-31 22:00:26Z siebrand $
 */
/** Catalan (català)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author David Gimeno i Ayuso <info@sima-pc.com>
 * @author Gemmaa
 * @author Martorell
 * @author MuRe
 * @author SMP
 * @author Solde
 * @author Ssola
 * @author Toniher
 */

$lang_locale = 'ca_ES.UTF-8';
$default_date_format = '%d/%m/%Y';
$no_locale_date_format = '%d/%m/%Y';
$default_time_format = '%H.%i';
$err_user_empty = 'El camp usuari és buit';
$err_passwd_empty = 'El camp contrasenya és buit';
$alt_delete = 'Esborrar missatges seleccionats';
$alt_delete_one = 'Esborrar el missatge';
$alt_new_msg = 'Missatges nous';
$alt_reply = 'Contestar al remitent';
$alt_reply_all = 'Contestar tothom';
$alt_forward = 'Reenviar';
$alt_next = 'Següent';
$alt_prev = 'Anterior';
$title_next_page = 'Pàgina següent';
$title_prev_page = 'Pàgina anterior';
$title_next_msg = 'Missatge següent';
$title_prev_msg = 'Missatge anterior';
$html_theme_label = 'Assumpte:';
$html_welcome = 'Benvingut a %1$s';
$html_login = 'Inicia una sessió';
$html_user_label = 'Usuari:';
$html_passwd_label = 'Contrasenya:';
$html_submit = 'Enviar';
$html_help = 'Ajuda';
$html_server_label = 'Servidor:';
$html_wrong = 'L\'usuari o la contrasenya són incorrectes';
$html_retry = 'Reintentar';
$html_remember = 'Recordar valors';
$html_lang_label = 'Idioma:';
$html_msgperpage_label = 'Missatges per pàgina:';
$html_preferences = 'Preferències';
$html_full_name_label = 'Nom complet:';
$html_email_address_label = 'Adreça de correu:';
$html_bccself = 'Envia\'m a mi una CCO';
$html_hide_addresses = 'Amagar adreces';
$html_outlook_quoting = 'Citar a l\'estil Outlook';
$html_reply_to = 'Contestar a';
$html_reply_to_label = 'Respondre a:';
$html_use_signature = 'Usar signatura';
$html_signature = 'Signatura';
$html_signature_label = 'Firma:';
$html_reply_leadin_label = 'Prefix de resposta:';
$html_prefs_updated = 'Preferències actualitzades';
$html_manage_folders_link = 'Gestionar carpetes IMAP';
$html_manage_filters_link = 'Gestionar filtres correu';
$html_use_graphical_smilies = 'Usar emoticones gràfiques';
$html_sent_folder_label = 'Copiar missatges enviats a una carpeta dedicada:';
$html_trash_folder_label = 'Mou els correus eliminats a la carpeta especificada:';
$html_colored_quotes = 'Notes acolorides';
$html_display_struct = 'Mostra el text estructurat';
$html_send_html_mail = 'Enviar el correu en format HTML';
$html_folders = 'Carpetes';
$html_folders_create_failed = 'No s\'ha pogut crear la carpeta!';
$html_folders_sub_failed = 'No us heu pogut subscriure a la carpeta!';
$html_folders_unsub_failed = 'No us heu pogut desafectar de la carpeta!';
$html_folders_rename_failed = 'No s\'ha pogut redenominar la carpeta!';
$html_folders_updated = 'Carpetes actualitzades';
$html_folder_subscribe = 'Subscriure a';
$html_folder_rename = 'Redenominar';
$html_folder_create = 'Crear carpeta nova anomenada';
$html_folder_remove = 'Desafectar de';
$html_folder_delete = 'Elimina';
$html_folder_to = 'a';
$html_filter_remove = 'Elimina';
$html_filter_body = 'Cos missatge';
$html_filter_subject = 'Assumpte missatge';
$html_filter_to = 'A';
$html_filter_cc = 'Còpia';
$html_filter_from = 'De';
$html_filter_change_tip = 'Per canviar un filtre, simplement sobreescriviu-lo.';
$html_reapply_filters = 'Reaplicar tots els filtres';
$html_filter_contains = 'conté';
$html_filter_name = 'Nom del filtre';
$html_filter_action = 'Acció del filtre';
$html_filter_moveto = 'Moure a';
$html_select_one = '--Seleccioneu-ne un--';
$html_and = 'i';
$html_new_msg_in = 'Missatges nous a';
$html_or = 'o';
$html_move = 'Moure';
$html_copy = 'Copiar';
$html_messages_to = 'missatges seleccionats a';
$html_gotopage = 'Anar a pàgina';
$html_gotofolder = 'Anar a carpeta';
$html_other_folders = 'Llita de carpetes';
$html_page = 'Pàgina';
$html_of = 'de';
$html_view_header = 'Veure capçalera';
$html_remove_header = 'Amagar capçalera';
$html_inbox = 'Entrada';
$html_new_msg = 'Escriure';
$html_reply = 'Contestar';
$html_reply_short = 'Re:';
$html_reply_all = 'Contestar tothom';
$html_forward = 'Reenviar';
$html_forward_short = 'Fwd:';
$html_forward_info = 'El missatge reenviat s\'enviarà com a adjunt.';
$html_delete = 'Elimina';
$html_new = 'Nou';
$html_mark = 'Elimina';
$html_att_label = 'Adjunt:';
$html_atts_label = 'Fitxers adjunts:';
$html_unknown = '[desconegut]';
$html_part_x = 'Part %s';
$html_attach = 'Adjuntar';
$html_attach_forget = 'Heu d\'adjuntar el fitxer abans d\'enviar el vostre missatge!';
$html_attach_delete = 'Suprimir els seleccionats';
$html_attach_none = 'Heu de seleccionar un fitxer per adjuntar!';
$html_sort_by = 'Ordenar per';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Assumpte';
$html_subject_label = 'Assumpte:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Enviar:';
$html_wrote = 'escrit';
$html_size = 'Mida';
$html_totalsize = 'Mida total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Fitxer';
$html_to = 'A';
$html_to_label = 'A:';
$html_cc = 'Còpia';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Sense assumpte';
$html_send = 'Enviar';
$html_cancel = 'Cancel·lar';
$html_no_mail = 'Cap missatge.';
$html_logout = 'Sortir';
$html_msg = 'Missatge';
$html_msgs = 'Missatges';
$html_configuration = 'Aquest servidor no està ben configurat!';
$html_priority = 'Prioritat';
$html_priority_label = 'Prioritat:';
$html_lowest = 'Baixa';
$html_low = 'Baixa';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'Alta';
$html_flagged = 'Senyalat';
$html_spam = 'Correu brossa';
$html_spam_warning = 'Aquest missatge ha estat classificat com a correu brossa.';
$html_receipt = 'Sol·licitar justificant de recepció';
$html_select = 'Seleccionar';
$html_select_all = 'Invertir selecció';
$html_select_contacts = 'Selecciona els contactes';
$html_loading_image = 'S\'està carregant la imatge';
$html_send_confirmed = 'El vostre correu s\'ha acceptat per entregar-lo';
$html_no_sendaction = 'No s\'ha especificat cap acció. Proveu d\'activar el Javascript.';
$html_error_occurred = 'Hi ha hagut un error';
$html_prefs_file_error = 'No s\'ha pogut obrir el fitxer de preferències per escriure-hi.';
$html_wrap = 'Nombre de caràcters a ajustar els missatges de sortida a:';
$html_wrap_none = 'Enlloc';
$html_usenet_separator = 'Separador Usenet ("-- \n") abans de la signatura';
$html_mark_as = 'Marcar com';
$html_read = 'llegit';
$html_unread = 'per llegir';
$html_encoding_label = 'Codificació:';
$html_add = 'Afegir';
$html_contacts = '%1$s contactes';
$html_modify = 'Modificar';
$html_back = 'Enrere';
$html_contact_add = 'Afegir contacte nou';
$html_contact_mod = 'Modificar un contacte';
$html_contact_first = 'Nom';
$html_contact_last = 'Cognoms';
$html_contact_nick = 'Renom';
$html_contact_mail = 'Correu';
$html_contact_list = 'Llista de contactes de %1$s';
$html_contact_del = 'de la llista de contactes';
$html_contact_count = '%1$d Contactes';
$html_contact_err1 = 'El mombre màxim de contactes és "%1$d"';
$html_contact_err2 = 'Nom podeu afegir cap més contacte';
$html_contact_err3 = 'No teniu drets d\'accés a la llista de contactes';
$html_contact_none = 'No s\'han trobat contactes.';
$html_del_msg = 'Esborrar missatges seleccionats?';
$html_down_mail = 'Descarregar';
$original_msg = '-- Missatge original --';
$to_empty = 'El camp \'A\' no pot ser buit!';
$html_images_warning = 'Per la seva seguretat, les imatges remotes no es mostraran.';
$html_images_display = 'Mostra les imatges';
$html_smtp_error_no_conn = 'No s\'ha pogut obrir la connexió SMTP';
$html_smtp_error_unexpected = 'Resposta SMTP inesperada:';
$lang_could_not_connect = 'No s\'ha pogut connectar al servidor';
$lang_invalid_msg_num = 'Número de missatge erroni';
$html_file_upload_attack = 'Possible atac de càrrega de fitxer';
$html_invalid_email_address = 'Adreça de correu incorrecta';
$html_invalid_msg_per_page = 'Nombre de missatges per pàgina incorrecte';
$html_invalid_wrap_msg = 'Ample d\'ajust de missatge incorrecte';
$html_seperate_msg_win = 'Missatge a finestres separades';
$html_err_file_contacts = 'No s\'ha pogut obrir el fitxer de contactes per escriure-hi.';
$html_session_file_error = 'No s\'ha pogut obrir el fitxer de sessió per a escriure.';
$html_login_not_allowed = 'L\'entrada no està permesa per connectar.';
$lang_err_send_delay = 'S\'ha d\'esperar entre dos correus electrònics (%1$d segons)';
$html_search = 'Cerca';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/ca.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ca.php 2656 2015-09-10 08:37:08Z siebrand $
 */
/** Catalan (català)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author David Gimeno i Ayuso <info@sima-pc.com>
 * @author Gemmaa
 * @author Martorell
 * @author MuRe
 * @author SMP
 * @author Solde
 * @author Ssola
 * @author Toniher
 */

$lang_locale = 'ca_ES.UTF-8';
$default_date_format = '%d/%m/%Y';
$no_locale_date_format = '%d/%m/%Y';
$default_time_format = '%H.%i';
$err_user_empty = 'El camp usuari és buit';
$err_passwd_empty = 'El camp contrasenya és buit';
$alt_delete = 'Esborrar missatges seleccionats';
$alt_delete_one = 'Esborrar el missatge';
$alt_new_msg = 'Missatges nous';
$alt_reply = 'Contestar al remitent';
$alt_reply_all = 'Contestar tothom';
$alt_forward = 'Reenviar';
$alt_next = 'Següent';
$alt_prev = 'Anterior';
$title_next_page = 'Pàgina següent';
$title_prev_page = 'Pàgina anterior';
$title_next_msg = 'Missatge següent';
$title_prev_msg = 'Missatge anterior';
$html_theme_label = 'Assumpte:';
$html_welcome = 'Benvingut a %1$s';
$html_login = 'Inicia una sessió';
$html_user_label = 'Usuari:';
$html_passwd_label = 'Contrasenya:';
$html_submit = 'Enviar';
$html_help = 'Ajuda';
$html_server_label = 'Servidor:';
$html_wrong = 'L\'usuari o la contrasenya són incorrectes';
$html_retry = 'Reintentar';
$html_remember = 'Recordar valors';
$html_lang_label = 'Idioma:';
$html_msgperpage_label = 'Missatges per pàgina:';
$html_preferences = 'Preferències';
$html_full_name_label = 'Nom complet:';
$html_email_address_label = 'Adreça de correu:';
$html_bccself = 'Envia\'m a mi una CCO';
$html_hide_addresses = 'Amagar adreces';
$html_outlook_quoting = 'Citar a l\'estil Outlook';
$html_reply_to = 'Contestar a';
$html_reply_to_label = 'Respondre a:';
$html_use_signature = 'Usar signatura';
$html_signature = 'Signatura';
$html_signature_label = 'Firma:';
$html_reply_leadin_label = 'Prefix de resposta:';
$html_prefs_updated = 'Preferències actualitzades';
$html_manage_folders_link = 'Gestionar carpetes IMAP';
$html_manage_filters_link = 'Gestionar filtres correu';
$html_use_graphical_smilies = 'Usar emoticones gràfiques';
$html_sent_folder_label = 'Copiar missatges enviats a una carpeta dedicada:';
$html_trash_folder_label = 'Mou els correus eliminats a la carpeta especificada:';
$html_colored_quotes = 'Notes acolorides';
$html_display_struct = 'Mostra el text estructurat';
$html_send_html_mail = 'Enviar el correu en format HTML';
$html_folders = 'Carpetes';
$html_folders_create_failed = 'No s\'ha pogut crear la carpeta!';
$html_folders_sub_failed = 'No us heu pogut subscriure a la carpeta!';
$html_folders_unsub_failed = 'No us heu pogut desafectar de la carpeta!';
$html_folders_rename_failed = 'No s\'ha pogut redenominar la carpeta!';
$html_folders_updated = 'Carpetes actualitzades';
$html_folder_subscribe = 'Subscriure a';
$html_folder_rename = 'Redenominar';
$html_folder_create = 'Crear carpeta nova anomenada';
$html_folder_remove = 'Desafectar de';
$html_folder_delete = 'Elimina';
$html_folder_to = 'a';
$html_filter_remove = 'Elimina';
$html_filter_body = 'Cos missatge';
$html_filter_subject = 'Assumpte missatge';
$html_filter_to = 'A';
$html_filter_cc = 'Còpia';
$html_filter_from = 'De';
$html_filter_change_tip = 'Per canviar un filtre, simplement sobreescriviu-lo.';
$html_reapply_filters = 'Reaplicar tots els filtres';
$html_filter_contains = 'conté';
$html_filter_name = 'Nom del filtre';
$html_filter_action = 'Acció del filtre';
$html_filter_moveto = 'Moure a';
$html_select_one = '--Seleccioneu-ne un--';
$html_and = 'i';
$html_new_msg_in = 'Missatges nous a';
$html_or = 'o';
$html_move = 'Moure';
$html_copy = 'Copiar';
$html_messages_to = 'missatges seleccionats a';
$html_gotopage = 'Vés a la pàgina';
$html_gotofolder = 'Anar a carpeta';
$html_other_folders = 'Llita de carpetes';
$html_page = 'Pàgina';
$html_of = 'de';
$html_view_header = 'Veure capçalera';
$html_remove_header = 'Amagar capçalera';
$html_inbox = 'Entrada';
$html_new_msg = 'Escriure';
$html_reply = 'Contestar';
$html_reply_short = 'Re:';
$html_reply_all = 'Contestar tothom';
$html_forward = 'Reenviar';
$html_forward_short = 'Fwd:';
$html_forward_info = 'El missatge reenviat s\'enviarà com a adjunt.';
$html_delete = 'Elimina';
$html_new = 'Nou';
$html_mark = 'Elimina';
$html_att_label = 'Adjunt:';
$html_atts_label = 'Fitxers adjunts:';
$html_unknown = '[desconegut]';
$html_part_x = 'Part %s';
$html_attach = 'Adjuntar';
$html_attach_forget = 'Heu d\'adjuntar el fitxer abans d\'enviar el vostre missatge!';
$html_attach_delete = 'Suprimir els seleccionats';
$html_attach_none = 'Heu de seleccionar un fitxer per adjuntar!';
$html_sort_by = 'Ordenar per';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Assumpte';
$html_subject_label = 'Assumpte:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Enviar:';
$html_wrote = 'escrit';
$html_size = 'Mida';
$html_totalsize = 'Mida total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Fitxer';
$html_to = 'A';
$html_to_label = 'A:';
$html_cc = 'Còpia';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Sense assumpte';
$html_send = 'Enviar';
$html_cancel = 'Cancel·lar';
$html_no_mail = 'Cap missatge.';
$html_logout = 'Sortir';
$html_msg = 'Missatge';
$html_msgs = 'Missatges';
$html_configuration = 'Aquest servidor no està ben configurat!';
$html_priority = 'Prioritat';
$html_priority_label = 'Prioritat:';
$html_lowest = 'Baixa';
$html_low = 'Baixa';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'Alta';
$html_flagged = 'Senyalat';
$html_spam = 'Correu brossa';
$html_spam_warning = 'Aquest missatge ha estat classificat com a correu brossa.';
$html_receipt = 'Sol·licitar justificant de recepció';
$html_select = 'Seleccionar';
$html_select_all = 'Invertir selecció';
$html_select_contacts = 'Selecciona els contactes';
$html_loading_image = 'S\'està carregant la imatge';
$html_send_confirmed = 'El vostre correu s\'ha acceptat per entregar-lo';
$html_no_sendaction = 'No s\'ha especificat cap acció. Proveu d\'activar el Javascript.';
$html_error_occurred = 'Hi ha hagut un error';
$html_prefs_file_error = 'No s\'ha pogut obrir el fitxer de preferències per escriure-hi.';
$html_wrap = 'Nombre de caràcters a ajustar els missatges de sortida a:';
$html_wrap_none = 'Enlloc';
$html_usenet_separator = 'Separador Usenet ("-- \n") abans de la signatura';
$html_mark_as = 'Marcar com';
$html_read = 'llegit';
$html_unread = 'per llegir';
$html_encoding_label = 'Codificació:';
$html_add = 'Afegir';
$html_contacts = '%1$s contactes';
$html_modify = 'Modificar';
$html_back = 'Enrere';
$html_contact_add = 'Afegir contacte nou';
$html_contact_mod = 'Modificar un contacte';
$html_contact_first = 'Nom';
$html_contact_last = 'Cognoms';
$html_contact_nick = 'Renom';
$html_contact_mail = 'Correu';
$html_contact_list = 'Llista de contactes de %1$s';
$html_contact_del = 'de la llista de contactes';
$html_contact_count = '%1$d Contactes';
$html_contact_err1 = 'El mombre màxim de contactes és "%1$d"';
$html_contact_err2 = 'Nom podeu afegir cap més contacte';
$html_contact_err3 = 'No teniu drets d\'accés a la llista de contactes';
$html_contact_none = 'No s\'han trobat contactes.';
$html_del_msg = 'Esborrar missatges seleccionats?';
$html_down_mail = 'Descarregar';
$original_msg = '-- Missatge original --';
$to_empty = 'El camp \'A\' no pot ser buit!';
$html_images_warning = 'Per la seva seguretat, les imatges remotes no es mostraran.';
$html_images_display = 'Mostra les imatges';
$html_smtp_error_no_conn = 'No s\'ha pogut obrir la connexió SMTP';
$html_smtp_error_unexpected = 'Resposta SMTP inesperada:';
$lang_could_not_connect = 'No s\'ha pogut connectar al servidor';
$lang_invalid_msg_num = 'Número de missatge erroni';
$html_file_upload_attack = 'Possible atac de càrrega de fitxer';
$html_invalid_email_address = 'Adreça de correu incorrecta';
$html_invalid_msg_per_page = 'Nombre de missatges per pàgina incorrecte';
$html_invalid_wrap_msg = 'Ample d\'ajust de missatge incorrecte';
$html_seperate_msg_win = 'Missatge a finestres separades';
$html_err_file_contacts = 'No s\'ha pogut obrir el fitxer de contactes per escriure-hi.';
$html_session_file_error = 'No s\'ha pogut obrir el fitxer de sessió per a escriure.';
$html_login_not_allowed = 'L\'entrada no està permesa per connectar.';
$lang_err_send_delay = 'S\'ha d\'esperar entre dos correus electrònics (%1$d segons)';
$html_search = 'Cerca';
